@@ -146,7 +146,7 @@ class RpcExchangerClient:
         log.debug(f"{self._chat_list=}")
         await self._exchanger.send_msg(self._username, msg, chat)    
     
-    async def recv(self, ignore_self_messages: bool=False) -> tuple[str, str, int]:
+    async def recv(self) -> tuple[str, str, int]:
         raw_message: Any = None
         username = ""
         msg = ""
@@ -160,12 +160,10 @@ class RpcExchangerClient:
             log.debug(f"{raw_message['data']=} {raw_message['channel']=}")
             try:
                 json_content = json.loads(raw_message["data"].decode())
-                username = json_content["username"]
-                msg = json_content["msg"]
+                username: str = json_content["username"]
+                msg: str = json_content["msg"]
                 chat = int(raw_message["channel"][9:])
                 log.debug(f"{username=} {msg=} {chat=}")
-                if ignore_self_messages and username == self._username:
-                    raw_message = None
             except Exception as e:
                 log.debug(e, exc_info=True)
                 raw_message = None
@@ -212,13 +210,25 @@ class RpcExchangerClient:
         result: list[tuple[int, str]] = [
             tuple(i) for i in await self._rpc.chat.list_somebody_joined(id=self._uid)
         ]
+        result_set = {i[0] for i in result}
         async with self._chat_list_lock:
-            for value, name in result:
-                if value not in self._chat_list:
-                    await self._pubsub.subscribe(f"messages:{value}")
-                    self._chat_list.add(value)
+            for i in self._chat_list - result_set:
+                # Chats quit or kicked
+                await self._pubsub.unsubscribe(f"messages:{i}")
+            for i in result_set - self._chat_list:
+                # Chats joined
+                await self._pubsub.subscribe(f"messages:{i}")
+            self._chat_list = result_set
         return result
 
+    async def chat_kick(self, chat_id: int, kicked_user_id: int) -> bool:
+        self.check_authorized()
+        return await self._rpc.chat.kick(chat_id=chat_id, user_id=self._uid, kicked_user_id=kicked_user_id)
+
+    async def chat_rename(self, chat_id: int, new_name: str) -> bool:
+        self.check_authorized()
+        return await self._rpc.chat.rename(chat_id=chat_id, user_id=self._uid, new_name=new_name)
+
     def __aiter__(self) -> RpcExchangerClient:
         return self
 
